#
# spec file for package python-geopy
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-geopy
Version:        1.10.0
Release:        6.2
Url:            http://code.google.com/p/geopy/
Summary:        Python Geocoding Toolbox
License:        MIT
Group:          Development/Languages/Python
Source:         https://pypi.python.org/packages/source/g/geopy/geopy-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python-devel >= 2.7
BuildRequires:  python-setuptools
BuildRequires:  python-simplejson
BuildRequires:  python-xml
Requires:       python-xml
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
Geopy makes it easy for developers to locate the coordinates of addresses, cities,
countries, and landmarks across the globe using third-party geocoders and other data
sources, such as wikis.

Geopy currently includes support for six geocoders: Google Maps, Yahoo! Maps, Windows
Local Live (Virtual Earth), geocoder.us, GeoNames, MediaWiki pages (with the GIS
extension), and Semantic MediaWiki pages.

%prep
%setup -q -n geopy-%{version}

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%defattr(-,root,root,-)
%doc LICENSE README
%{python_sitelib}

%changelog
* Tue May  5 2015 benoit.monin@gmx.fr
- update to version 1.10.0:
  * CHANGED: GeocodeFarm now uses version 3 of the service’s API,
    which allows use by unauthenticated users, multiple results,
    and SSL/TLS. You may need to obtain a new API key from
    GeocodeFarm, or use None for their free tier. Contributed by
    Eric Palakovich Carr.
  * ADDED: DataBC geocoder for use with the British Columbia
    government’s DataBC service. Contributed by Benjamin
    Trigona-Harany.
  * ADDED: Placefinder’s geocode method now requests a timezone if
    the with_timezone parameter is true. Contributed by willr.
  * FIXED: Nominatim specifies a viewbox parameter rather than the
    apparently deprecated view_box.
- additional changes from version 1.9.1:
  * FIXED: Fix support for GoogleV3 bounds parameter. Contributed
    by Benjamin Trigona-Harany.
- additional changes from version 1.9.0:
  * CHANGED: MapQuest geocoder removed as the API it uses is now
    only available to enterprise accounts. OpenMapQuest is a
    replacement for Nominatim-sourced data.
  * CHANGED: Nominatim now uses HTTPS by default and accepts a
    scheme argument. Contributed by srounet.
  * ADDED: Nominatim now accepts a domain argument, which allows
    using a different server than nominatim.openstreetmap.org.
    Contributed by srounet.
  * FIXED: Bing was not accessible from get_geocoder_for_service.
    Contributed by Adrián López.
- additional changes from version 1.8.1:
  * FIXED: GoogleV3 geocoder did not send API keys for reverse and
    timezone methods.
- additional changes from version 1.8.0:
  * ADDED: NaviData geocoder added. Contributed by NaviData.
  * CHANGED: LiveAddress now requires HTTPS connections. If you set
    scheme to be http, rather than the default https, you will now
    receive a ConfigurationError.
- additional changes from version 1.7.1:
  * FIXED: IGN France geocoder’s address formatting better handles
    results that do not have a building number. Contributed by
    Thomas Gratier.
- additional changes from version 1.7.0:
  * ADDED: IGN France geocoder. Contributed by Thomas Gratier.
  * FIXED: Bing checks the response body for error codes.
- additional changes from version 1.6.1:
  * FIXED: What3Words validation loosened. Contributed by
    spatialbitz.
  * FIXED: Point.format() includes altitude.
- additional changes from version 1.6.0:
  * ADDED: Python 3.2 and PyPy3 compatibility. Contributed by Mike
    Toews.
- additional changes from version 1.5.0:
  * ADDED: Yandex geocoder added. Contributed by htch.
  * ADDED: What3Words geocoder added. Contributed by spatialbitz.
  * FIXED: LiveAddress geocoder made compatible with a change in
    the service’s authentication. An auth_id parameter was added to
    the geocoder’s initialization. Contributed by Arsen Mamikonyan.
- additional changes from version 1.4.0:
  * ADDED: Mapquest.reverse() method added. Contributed by Dody
    Suria Wijaya.
  * ADDED: Bing’s geocoder now accepts the optional arguments
    “culture”, “includeNeighborhood”, and “include”. Contributed by
    oskholl.
- additional changes from version 1.3.0:
  * ADDED: Nominatim.geocode() accepts a geometry argument for
    retrieving wkt, svg, kml, or geojson formatted geometries in
    results. Contributed by spatialbitz.
- additional changes from version 1.2.0:
  * ADDED: GeoNames.reverse() added. Contributed by Emile Aben.
  * ADDED: GoogleV3.timezone() added. This returns a pytz object
    giving the timezone in effect for a given location at a time
    (defaulting to now).
- additional changes from version 1.1.5:
  * FIXED: YahooPlaceFinder is now compatible with the older
    requests_oauthlib version 0.4.0.
- additional changes from version 1.1.4:
  * FIXED: Point.format() seconds precision in Python 3.
- additional changes from version 1.1.3:
  * FIXED: Fix OpenCage AttributeError on empty result. Contributed
    by IsaacHaze.
- additional changes from version 1.1.2:
  * FIXED: Update Point __repr__ method to format _items properly.
    Contributed by TristanH.
- additional changes from version 1.1.1:
  * FIXED: Python 3 compatibility.
- additional changes from version 1.1.0:
  * ADDED: OpenCage geocoder added. Contributed by Demeter Sztanko.
  * ADDED: geopy.geocoders.get_geocoder_for_service allows library
    authors to dynamically get a geocoder.
  * FIXED: YahooPlacefinder bugs causing geocoding failure.
  * FIXED: LiveAddress API URL updated.
  * FIXED: Location.__repr__ unicode encode error in Python 2.7.
  * CHANGED: geopy.geocoders modules now strictly declare their
    exports.
- additional changes from version 1.0.1:
  * FIXED: The Baidu Maps geocoder’s _check_status method used a
    Python 2-specific print statement.
- additional changes from version 1.0.0:
  * ADDED: Baidu Maps geocoder added. Contributed by Risent.
  * ADDED: Nominatim geocoder now supports structured queries.
    Contributed by kpanic.
  * ADDED: Nominatim geocoder now supports a language parameter.
    Contributed by Benjamin Henne.
  * CHANGED: GoogleV3’s geocode and reverse methods have different
    orders for keyword argument parameters. Geocoders are now
    standardized on (query, exactly_one, timeout, ...).
  * FIXED: Removed rounding of minutes which was causing a
    formatted point to always have zero seconds. Contributed by
    Jonathan Batchelor.
- additional changes from version 0.99:
  * ADDED: GeocodeFarm geocoder added with support for geocoding
    and reverse geocoding. Contributed by Eric Palakovich Carr.
- additional changes from version 0.98.3:
  * ADDED: Queries are encoded as unicode in Python 2.7 by the
    geocoder. Contributed by Rocky Meza.
  * FIXED: YahooPlaceFinder count parameter fixed.
  * FIXED: Point.__repr__ fixed. Contributed by Paweł Mandera.
- additional changes from version 0.98.2:
  * ADDED: GoogleV3 now accepts an api_key parameter. Contributed
    by Andrea Tosatto.
  * CHANGED: GoogleV3’s deprecated protocol argument has been
    removed.
- additional changes from version 0.98.1:
  * FIXED: Mapquest geocoder did not use format_string in the
    creation of its queries. Contributed by Danny Finkelstein.
  * FIXED: Geocoders incorrectly raised a GeocoderTimedOut
    exception for all SSLError exceptions. Contributed by David
    Gilman.
- additional changes from version 0.98:
  * CHANGED: Geocoders’ geocode and reverse method return types
    have changed from None, a tuple, or a list of tuples, to None,
    a geopy.Location object, or a list of geopy.Location objects.
- additional changes from version 0.97.1:
  * FIXED:YahooPlaceFinder geocoder authentication and response
    parsing fixed. Contributed by petergx.
  * ADDED: GoogleV3 geocoding now supports a components parameter,
    which is a filter for location criteria such as administrative
    area, country, etc. Contributed by crccheck.
- additional changes from version 0.97:
  * CHANGED: SSL connections are used by default for services with
    support. These geocoders accept a new ‘scheme’ argument in
    their init, which may be ‘https’ or ‘http’. Users desiring
    unencrypted connections must now specify ‘http’. Note that SSL
    connections’ certificates are not verified.
  * CHANGED: Geocoders accept a timeout argument which specifies
    the number of seconds to wait before raising a GeocoderTimedOut
    exception. This can be specified in the init, or specified
    one-off in each geocode or reverse call. There is now a default
    of 1 second.
  * CHANGED: geopy now supports Python 2 and Python 3 on a single
    codebase. Support for Python 2.5 is also dropped.
  * CHANGED: GoogleV3’s protocol argument is deprecated in favor of
    scheme.
  * ADDED: ESRI’s ArcGIS geocoder implemented. Contributed by Arsen
    Mamikonyan.
  * ADDED: Geocoders accept a proxies argument which specifies a
    proxy to route its geocoder requests through. It uses urllib,
    and accepts proxies in the form of a dictionary of {scheme:
    proxy address}, e.g., {“https”: “192.0.2.0”}. This was present
    but undocumented in 0.96.
  * ADDED: Geocoders check a new method,
    _geocoder_exception_handler, if defined, when the HTTP call to
    the geocoder’s service raises an exception. See LiveStreets for
    an example. Users can define or override this method.
  * ADDED: LiveStreets throws a GeocoderQuotaExceeded exception
    when appropriate.
  * ADDED: Point can parse a greater variety of coordinate strings.
    Contributed by nucflash.
  * FIXED: GeocodersDotUS now authenticates with an Authorization
    HTTP header. Contributed by Arsen Mamikonyan.
  * REMOVED: MediaWiki and SemanticMediaWiki geocoders removed.
  * REMOVED: Geohash module has been removed.
- additional changes from version 0.96.3:
  * ADDED: Documentation warning that the Vincenty distance
    implementation fails to converge for some valid points.
    Reported by mkeller-upb.
  * FIXED: Geocoder proxying fixed. Contributed by Marc-Olivier
    Titeux.
- limit build to python 2.7
- remove RELEASES from package files: not provided anymore
* Wed Dec 11 2013 p.drouand@gmail.com
- Update to version 0.96.2
  + fix : MANIFEST.in should not use `exclude`.
- Changes from 0.96.1
  + fix : GoogleV3 returns `None` when the service returns an error
    status of `ZERO_RESULTS`.
- Changes from 0.96.0
  + GoogleV3's reverse geocoder now returns one result by default. Set
    `exactly_one` to False for a list.
  + GoogleV3 returns new exception types:
    `geopy.geocoders.base.GQueryError` -> `geopy.exc.GeocoderQueryError`
    `geopy.geocoders.base.GeocoderResultError` -> `geopy.exc.GeocoderQueryError`
    `geopy.geocoders.base.GTooManyQueriesError` -> `geopy.exc.GeocoderQuotaExceeded`
  + OpenStreetMap Nominatim geocoder implemented.
  + Yahoo! BOSS Geo PlaceFinder geocoder implemented.
  + SmartyStreets LiveAddress geocoder implemented.
  + GeoNames geocoder is implements GeoNames' new username
    requirement and `api.geonames.org` endpoint.
  + Bing geocoder supports `user_location` (`Point`) parameter. Bing will
    prefer results near the coordinates of `user_location`.
  + `GoogleV3.geocode_first()` no longer throws exception on multiple
    results.
  + Unnecessary coercing to UTF-8 on Py3k.
  +`format_degrees` now rounds minutes properly.
  + No longer warn if the optional dependency `BeautifulSoup` is
    not present.
  + Miscellaneous inconsistent behavior and errors in geolocating.
  + Google V2 geocoder has been removed as its API was shutdown.
- Changes from
  + Fix #12, where `DeprecationWarning` was showing for GoogleV2 even if
    it wasn't being used (due to `geopy.geocoders` importing it).
  + `GoogleV3.geocode` "address" kwarg renamed to "string" to match
    `Google.geocode` to make updating easier.
  + Geocoders now properly handle Unicode objects as input (previously
    would fail on non-ASCII characters due to wanting UTF-8 strings).
- Changes from 0.95
  + Google Geocoding API V3 support. "google.Google()" should be
    replaced by "googlev3.GoogleV3()", with no `api_key`.
    Please see http://goo.gl/somDT for valid arguments.
  + setup.py updated to now automatically support Python 3+
    (via 2to3 auto-compile option).
- Package LICENSE, README and RELEASES in documentation directory
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Tue Mar 13 2012 alexandre@exatati.com.br
- Update to 0.94.2:
  ADDED:   MANIFEST.in so that LICENSE file gets included in dist
    packages (per req by Debian Python Module Team)
  UPDATED: Yahoo geocoder uses new PlaceFinder API instead of
    outdated MapsService V1 API.
* Wed Sep 21 2011 saschpe@suse.de
- Spec file cleanup:
  * Removed %%clean section (not needed anymore)
  * Removed CFLAGS (not a C extension)
* Thu Mar 24 2011 alexandre@exatati.com.br
- Update to 0.94.1;
- Regenerated spec file with py2pack.
* Tue Mar  9 2010 alexandre@exatati.com.br
- Update to 0.94;
- Building as noarch for openSUSE >= 11.2.
* Tue Aug 18 2009 alexandre@exatati.com.br
- Initial package (0.93) for openSUSE.
